@@ -13,7 +13,7 @@ use IO::Uncompress::Gunzip();
 use JSON();
 use overload '""' => 'string';
 
-our $VERSION = 0.18;
+our $VERSION = 0.19;
 
 sub new {
     my ( $class, $params ) = @_;
@@ -488,7 +488,7 @@ Archive::Har - Provides an interface to HTTP Archive (HAR) files
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =for stopwords xml gzip stringified HAR gzipped gzipping JSON hashref gunzipping
 
@@ -589,7 +589,10 @@ Archive::Har requires the following non-core Perl modules
 L<JSON|JSON>
 
 =item *
-L<Compress::Zlib|Compress::Zlib>
+L<IO::Compress::Gzip|IO::Compress:Gzip>
+
+=item *
+L<IO::Uncompress::Gunzip|IO::Uncompress:Gunzip>
 
 =item *
 L<XML::LibXML|XML::LibXML>
